EXSWHTEC-363 - Implement tests for Surface Management APIs (#439)
Change-Id: If354846b04fb48974cd0345f3a317e52b046014f
This commit is contained in:
committed by
Rakesh Roy
parent
dbc1a9d073
commit
7685c9c46a
@@ -0,0 +1,66 @@
|
||||
/*
|
||||
Copyright (c) 2023 Advanced Micro Devices, Inc. All rights reserved.
|
||||
|
||||
Permission is hereby granted, free of charge, to any person obtaining a copy
|
||||
of this software and associated documentation files (the "Software"), to deal
|
||||
in the Software without restriction, including without limitation the rights
|
||||
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
|
||||
copies of the Software, and to permit persons to whom the Software is
|
||||
furnished to do so, subject to the following conditions:
|
||||
|
||||
The above copyright notice and this permission notice shall be included in
|
||||
all copies or substantial portions of the Software.
|
||||
|
||||
THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
|
||||
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
|
||||
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
|
||||
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
|
||||
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
|
||||
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
|
||||
THE SOFTWARE.
|
||||
*/
|
||||
|
||||
#include <hip_test_common.hh>
|
||||
|
||||
/**
|
||||
* @addtogroup hipDestroySurfaceObject hipDestroySurfaceObject
|
||||
* @{
|
||||
* @ingroup SurfaceTest
|
||||
*/
|
||||
|
||||
/**
|
||||
* Test Description
|
||||
* ------------------------
|
||||
* - Negative parameters test for `hipDestroySurfaceObject`.
|
||||
* Test source
|
||||
* ------------------------
|
||||
* - unit/texture/hipDestroySurfaceObject.cc
|
||||
* Test requirements
|
||||
* ------------------------
|
||||
* - HIP_VERSION >= 5.7
|
||||
*/
|
||||
TEST_CASE("Unit_hipDestroySurfaceObject_Negative_Parameters") {
|
||||
SECTION("surfObject is NULL") {
|
||||
HIP_CHECK(hipDestroySurfaceObject(static_cast<hipSurfaceObject_t>(0)));
|
||||
}
|
||||
|
||||
SECTION("double free") {
|
||||
hipArray_t array;
|
||||
hipChannelFormatDesc desc = hipCreateChannelDesc<float>();
|
||||
|
||||
HIP_CHECK(hipMallocArray(&array, &desc, 64, 0, hipArraySurfaceLoadStore));
|
||||
|
||||
hipSurfaceObject_t surf;
|
||||
|
||||
hipResourceDesc resc = {};
|
||||
resc.resType = hipResourceTypeArray;
|
||||
resc.res.array.array = array;
|
||||
|
||||
HIP_CHECK(hipCreateSurfaceObject(&surf, &resc));
|
||||
|
||||
HIP_CHECK(hipDestroySurfaceObject(surf));
|
||||
HIP_CHECK_ERROR(hipDestroySurfaceObject(surf), hipErrorInvalidValue);
|
||||
|
||||
HIP_CHECK(hipFreeArray(array));
|
||||
}
|
||||
}
|
||||
Reference in New Issue
Block a user